@@ -130,7 +130,7 @@ class avconv(devedeng.avbase.avbase):
             second_pass = False
         else:
             # second_pass is TRUE in the second pass of a 2-pass codification, and also when not doing 2-pass codification
-            # It is used to remove unnecessary steps during the first pass, but that are needed on the second pass, or when not using 2-pass codification 
+            # It is used to remove unnecessary steps during the first pass, but that are needed on the second pass, or when not using 2-pass codification
             second_pass = True
 
         if (video_length == 0):
@@ -144,7 +144,7 @@ class avconv(devedeng.avbase.avbase):
 
         if (file_project.volume!=100) and second_pass:
             self.command_var.append("-vol")
-            self.command_var.append(str((256*file_project.volume)/100))
+            self.command_var.append(str(int((256*file_project.volume)/100)))
 
         if (file_project.audio_delay != 0.0) and (file_project.copy_sound==False) and (file_project.no_reencode_audio_video==False) and second_pass:
             self.command_var.append("-itsoffset")
@@ -433,4 +433,4 @@ class avconv(devedeng.avbase.avbase):
                     t += float(e)
                 t /= self.final_length
                 self.progress_bar[1].set_fraction(t)
-                self.progress_bar[1].set_text("%.1f%%" % (100.0 * t))
\ No newline at end of file
+                self.progress_bar[1].set_text("%.1f%%" % (100.0 * t))
